@@ -19,7 +19,7 @@ function(menu = FALSE){
     a <- utils::available.packages()
     b <- rownames(a)  
     if(menu){
-        b <- select.list(b, title = "CRAN packages")
+        b <- utils::select.list(b, title = "CRAN packages")
     }
     
     return(b)          
@@ -37,6 +37,6 @@ p_iscran <- function(package) {
     if (!object_check(package) || !is.character(package)) {
         package <- as.character(substitute(package))
     }
-    available_packages <- rownames(available.packages())
+    available_packages <- rownames(utils::available.packages())
     package %in% available_packages
 }
